@@ -2,7 +2,7 @@ from .component_text import ComponentTextEntry
 from .svg import SvgEntry
 from .text import TextEntry
 from .image import ImageEntry
-from .cards import CardsEntry
+from .cards import CardsEntry, StreamCard
 from .grid_info import GridInfoEntry
 from .medias_line import MediasLineEntry
 from .timeline import TimeLineEntry
